unit Manual;

interface

uses
  ComObj, Windows, ActiveX, COMSVCSLib_TLB, ASPTypeLibrary_TLB, asp2102_TLB,
  StdVcl;

type
  TManual = class(TAutoObject, IManual, ObjectControl)
  private
    m_piObjContext  : ObjectContext;
    m_piResponse    : Response;
    m_piRequest     : Request;
    m_piSession     : Session;
    m_piServer      : Server;
    m_piApplication : Application;
  protected
    function  Activate: HResult; stdcall;
    function  Deactivate: HResult; stdcall;
    function  CanBePooled(out pbPoolable: WordBool): HResult; stdcall;
    procedure OnAccessValue; safecall;
    procedure getContents; safecall;
    procedure showVariables; safecall;
    procedure encodeValues(const bstrHTML, bstrURL, bstrPath,
      bstrMap: WideString); safecall;
  public
    procedure sayHi(const bstrName: WideString); safecall;
    function testObjContext: WideString; safecall;
  end;

implementation

uses ComServ;

function TManual.Activate: HRESULT;
var
   mtx: IMTxAS;
   piIdisp: IDispatch;
begin
mtx := CoAppServer.Create;
m_piObjContext := mtx.GetObjectContext;

// get response
piIdisp := m_piObjContext.Get_Item('Response');
m_piResponse := piIdisp As IResponse;

// get request
piIdisp := m_piObjContext.Get_Item('Request');
m_piRequest := piIdisp As IRequest;

// get session
piIdisp := m_piObjContext.Get_Item('Session');
m_piSession := piIdisp As ISessionObject;

// get application
piIdisp := m_piObjContext.Get_Item('Application');
m_piApplication := piIdisp As IApplicationObject;

// get response
piIdisp := m_piObjContext.Get_Item('Server');
m_piServer := piIdisp As IServer;

Activate := S_OK;
end;

function TManual.Deactivate: HRESULT;
begin
m_piResponse._Release;
m_piRequest._Release;
m_piSession._Release;
m_piApplication._Release;
m_piServer._Release;
Deactivate := S_OK;
end;

function  TManual.CanBePooled(out pbPoolable: WordBool): HResult; stdcall;
begin
  pbPoolable := False;
  CanBePooled := S_OK;
end;

procedure TManual.sayHi(const bstrName: WideString);
var
tmpString : WideString;
tmpVt : OleVariant;
begin
tmpString := 'Hello ' + bstrName;
tmpVt := tmpString;
m_piResponse.Write(tmpVt);
m_piObjContext.SetComplete;
end;

function TManual.testObjContext: WideString;
var
tmpStr : WideString;
begin
if m_piObjContext.IsInTransaction Then
   tmpStr := 'In Transaction'
else
   tmpStr := 'Not in Transaction';

m_piObjContext.SetComplete;
testObjContext := tmpStr;
end;

procedure TManual.OnAccessValue;
var
iCounter : Integer;
begin
 iCounter := m_piApplication.Contents.Get_Item('intCounter');
 iCounter := iCounter + 1;
 m_piApplication.Contents.Set_Item('intCounter',iCounter);
end;

procedure TManual.getContents;
var
piDict: IVariantDictionary;
iCount: Integer;
iTotal: Integer;
ovName: OleVariant;
ovValue: OleVariant;
begin

// get contents
piDict := m_piSession.Get_Contents;
iTotal := piDict.Count;

for iCount := 1 to iTotal do
begin
  // get name
  ovName := piDict.Get_Key(iCount);
  m_piResponse.Write(ovName);
  m_piResponse.Write(' = ');

  // print value
  ovValue := m_piSession.Get_Value(ovName);
  m_piResponse.Write(ovValue);
  m_piResponse.Write('<p>');
end;

end;

procedure TManual.showVariables;
var
  piReqDict: IRequestDictionary;
  piIEnum: IEnumVariant;
  piIUnknown: IUnknown;
  liReturn: LongWord;
  ovName: OleVariant;
  ovValue: OleVariant;
begin

  // get ServerVariables and enum for variables
  piReqDict := m_piRequest.Get_ServerVariables;
  piIUnknown := piReqDict.Get__NewEnum;
  piIEnum := piIUnknown As IEnumVariant;

  // while S_OK get name and value, print
  while piIEnum.Next(1,ovName,liReturn) = S_OK do
    begin;
      m_piResponse.Write(ovName);
      m_piResponse.Write(' = ');

      ovValue := piReqDict.Get_Item(ovName);

      m_piResponse.Write(ovValue);
      m_piResponse.Write('<br>');
    end;

end;

procedure TManual.encodeValues(const bstrHTML, bstrURL, bstrPath,
  bstrMap: WideString);
var
strHTML : WideString;
strURL  : WideString;
strPath : WideString;
strMap  : WideString;
begin

// encode values
strHTML := m_piServer.HTMLEncode(bstrHTML);
strURL  := m_piServer.URLEncode(bstrURL);
strPath := m_piServer.URLPathEncode(bstrPath);
strMap  := m_piServer.MapPath(bstrMap);

// print values
m_piResponse.Write(strHTML);
m_piResponse.Write('<br>');
m_piResponse.Write(strURL);
m_piResponse.Write('<br>');
m_piResponse.Write(strPath);
m_piResponse.Write('<br>');
m_piResponse.Write(strMap);

end;

initialization
  TAutoObjectFactory.Create(ComServer, TManual, Class_Manual,
    ciMultiInstance, tmBoth);
end.
